@@ -17,9 +17,13 @@ from .types import (
     NumberRangeType,
     ScalarListType,
     ScalarListException,
+    TSVectorType
 )
 
 
+__version__ = '0.14.4'
+
+
 __all__ = (
     coercion_listener,
     sort_query,
@@ -43,4 +47,5 @@ __all__ = (
     ProxyDict,
     ScalarListType,
     ScalarListException,
+    TSVectorType
 )
